@@ -326,9 +326,11 @@ class Gateway():
             return command.status
 
     async def gatewayReady(self):
-        if await self.gatewayState() == "READY":
+        state = await self.gatewayState() 
+        if state == "READY":
             return
         else:
+            _LOGGER.exception("Gateway state error: " + state)
             raise GatewayError
 
     async def getVersionG(self):
